@@ -29,25 +29,33 @@
 
 #include <glib.h>
 
-#define OBEX_OPUSH	0x00
-#define OBEX_FTP	0x01
+#define OBEX_OPP	(1 << 0)
+#define OBEX_FTP	(1 << 2)
+#define OBEX_BIP	(1 << 3)
+#define OBEX_PBAP	(1 << 4)
 
 #define OBJECT_SIZE_UNKNOWN -1
 #define OBJECT_SIZE_DELETE -2
 
 struct obex_commands {
 	void (*get) (obex_t *obex, obex_object_t *obj);
-	gint (*chkput) (obex_t *obex, obex_object_t *obj);
 	void (*put) (obex_t *obex, obex_object_t *obj);
+	gint (*chkput) (obex_t *obex, obex_object_t *obj);
 	void (*setpath) (obex_t *obex, obex_object_t *obj);
 };
 
 struct server {
-	guint16		service;
+	guint16		services;
 	gboolean	auto_accept;
+	gchar		*name;
 	gchar		*folder;
 	gchar		*capability;
 	guint32		handle;
+	uint8_t		channel;
+	gchar		*devnode;
+	gboolean	secure;
+	GIOChannel	*io;
+	guint		watch;
 };
 
 struct obex_session {
@@ -73,14 +81,21 @@ struct obex_session {
 gint obex_session_start(gint fd, struct server *server);
 gint obex_session_stop();
 
-gint opp_chkput(obex_t *obex, obex_object_t *obj);
-void opp_put(obex_t *obex, obex_object_t *obj);
 void opp_get(obex_t *obex, obex_object_t *obj);
+void opp_put(obex_t *obex, obex_object_t *obj);
+gint opp_chkput(obex_t *obex, obex_object_t *obj);
 
 void ftp_get(obex_t *obex, obex_object_t *obj);
 void ftp_put(obex_t *obex, obex_object_t *obj);
-void ftp_setpath(obex_t *obex, obex_object_t *obj);
 gint ftp_chkput(obex_t *obex, obex_object_t *obj);
+void ftp_setpath(obex_t *obex, obex_object_t *obj);
+
+void pbap_get(obex_t *obex, obex_object_t *obj);
 
 gboolean os_prepare_get(struct obex_session *os, gchar *file, guint32 *size);
 gint os_prepare_put(struct obex_session *os);
+
+void server_free(struct server *server);
+
+int tty_init(gint service, const gchar *folder, const gchar *capability,
+		const gchar *devnode);
